@@ -1,6 +1,4 @@
-# Korea.pm
-# by Martin Thurn
-# $Id: Korea.pm,v 1.6 2003/12/30 04:19:44 Daddy Exp $
+# $Id: Korea.pm,v 2.31 2004/02/17 13:13:07 Daddy Exp $
 
 =head1 NAME
 
@@ -19,7 +17,7 @@ WWW::Search::Yahoo::Korea - class for searching Yahoo! Korea
 
 This class is a Yahoo! Korea specialization of L<WWW::Search>.  It
 handles making and interpreting searches on Yahoo! Korea
-F<http://uk.yahoo.com>.
+F<http://kr.yahoo.com>.
 
 This class exports no public interface; all interaction should
 be done through L<WWW::Search> objects.
@@ -49,18 +47,6 @@ THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
-=head1 VERSION HISTORY
-
-If it''s not listed here, then it wasn''t a meaningful nor released revision.
-
-=head2 2.02
-
-minor pod update
-
-=head2 2.01, 2001-03-30
-
-First public release.
-
 =cut
 
 #####################################################################
@@ -74,10 +60,9 @@ use strict;
 use vars qw( @ISA $VERSION $MAINTAINER );
 @ISA = qw( WWW::Search::Yahoo );
 
-$VERSION = '2.02';
+$VERSION = do { my @r = (q$Revision: 2.31 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
-
 sub native_setup_search
   {
   my ($self, $sQuery, $rh) = @_;
